##  Managing Processors
  * Updating the configuration: To update the processor configuration, make the necessary changes and then click Save. Note that the system doesn't save input data.
  * Updating the integrated tool: You can update the integrated tool associated with the processor from the Integration API page.
  * Deleting a processor: Be cautious with this action, as it cannot be undone. To delete a processor, click the three-dot icon in the upper-right corner of the processor page, then select Delete Configuration.
